"""Module for global PyVLX logging object."""
import logging

PYVLXLOG = logging.getLogger("pyvlx")
